@@ -7,7 +7,7 @@ use warnings;
 package Acme::ConspiracyTheory::Random;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.012';
+our $VERSION   = '0.013';
 
 use Exporter::Shiny qw( theory bad_punctuation );
 use List::Util 1.54 ();
@@ -67,7 +67,7 @@ sub shady_group {
 			{ plural => 0, name => 'the Ordo Templi Orientis' },
 			{ plural => 1, name => 'the Cabalists' },
 			{ plural => 1, name => 'the Followers of the Temple Of The Vampire', shortname => 'the Vampires' },
-			{ plural => 0, name => 'the Secret Order of the Knights of the Round Table', shortname => 'the Knights' },
+			{ plural => 0, splural => 1, name => 'the Secret Order of the Knights of the Round Table', shortname => 'the Knights' },
 			{ plural => 1, name => 'the Cardinals of the Catholic Church', shortname => 'the Cardinals' },
 			{ plural => 0, name => 'the Church of Satan', shortname => 'the Church' },
 			{ plural => 1, name => 'the Gnostics' },
@@ -193,6 +193,21 @@ sub objects {
 	return $objects;
 }
 
+sub invention {
+	my $redstring = shift // {};
+	
+	my $invention = _RANDOM_(
+		['the internet', 0],
+		['cryptocurrencies', 1],
+		['smartphones', 1],
+		['bitcoin', 0],
+	);
+	
+	_MERGE_( $redstring, invention => $invention->[0],
+		 invention_plural => $invention->[1], );
+	return $invention->[0];
+}
+
 sub shady_project {
 	my $redstring = shift // {};
 	
@@ -205,6 +220,7 @@ sub shady_project {
 		'the LGBT Agenda',
 		'the Kalergi Plan',
 		'Eurabia',
+		'the moon-landing hoax',
 	);
 	
 	_MERGE_( $redstring, shady_project => $x );
@@ -331,7 +347,7 @@ sub attribute {
 		'horny',
 		'female',
 		'fat',
-		'flourescent',
+		'fluorescent',
 	);
 	
 	_MERGE_( $redstring, attribute => $attr );
@@ -352,7 +368,7 @@ sub artifact {
 		'the Necronomicon',
 		"the Philosopher's Stone",
 		"a fragment of the true cross",
-		"the seal of Soloman",
+		"the seal of Solomon",
 	);
 	
 	_MERGE_( $redstring, artifact => $artifact );
@@ -582,7 +598,7 @@ sub a_long_time {
 		'since time immemorial',
 		'since the dawn of time',
 		'for hundreds of years',
-		'for millenia',
+		'for millennia',
 		@extras,
 	);
 	
@@ -747,6 +763,8 @@ sub fatuous {
 		"Wake up, sheeple!",
 		"It's obvious if you connect the dots.",
 		"They leave clues to mock us.",
+		"It's not funny!",
+		"There are too many coincidences to ignore.",
 	);
 
 	_MERGE_( $redstring, clone => $x );
@@ -772,6 +790,19 @@ sub clone {
 	return $x;
 }
 
+sub lies {
+	my $redstring = shift // {};
+
+	my $x = _RANDOM_(
+		'obvious lies',
+		'a big coverup',
+		'a fairy tale',
+		'disinformation',
+	);
+	
+	_MERGE_( $redstring, lies => $x );
+	return $x;
+}
 
 sub evidence {
 	my $redstring = shift // {};
@@ -795,6 +826,7 @@ sub evidence {
 		push @x, (
 			"they indoctrinate people about '$m' at schools and if it were the truth they wouldn't need to",
 			"'$m' gets pushed down our throats by mass media",
+			"'$m' is a false-flag operation",
 		);
 	}
 	
@@ -1040,6 +1072,8 @@ sub evidence {
 		
 		( my $fbname = $name ) =~ s/^the //i;
 		$fbname = _UCFIRST_ $fbname;
+
+		my $lies = lies();
 		
 		push @x, (
 			"$name $have included it in their manifesto",
@@ -1050,7 +1084,7 @@ sub evidence {
 			"the '$fbname Truth' Facebook page says so",
 			"the '$fbname Exposed' website says so",
 			"$name even admit$s it",
-			"$name den$ies it but that is obvious lies",
+			"$name den$ies it but that is $lies",
 		);
 		
 		if ( my $animal = $redstring->{real_animal} // $redstring->{fake_animal} ) {
@@ -1244,6 +1278,10 @@ sub hidden_truth {
 					$redstring->{topic} = { name => 'Nazis', plural => 1 };
 					"there is a Nazi base in Antarctica";
 				},
+				sub {
+					$redstring->{topic} = { name => 'wrestling', plural => 0 };
+					"all professional sports are scripted";
+				},
 				sub {
 					my $website = website( $redstring );
 					my $spies   = _RANDOM_(
@@ -1320,6 +1358,7 @@ sub hidden_truth {
 		sub {
 			my $celebrity = celebrity( $redstring );
 			$redstring->{topic} = { name => 'cross-dressing', plural => 0 };
+			$redstring->{celebrity}{female} = ! $redstring->{celebrity}{female};
 			"$celebrity is transsexual";
 		},
 		sub {
@@ -1493,6 +1532,22 @@ sub hidden_truth {
 			$redstring->{real_animal} //= $extinct;
 			"the $extinct is not extinct and there is a colony in $p";
 		},
+		sub {
+			my $group   = shady_group( $redstring );
+			my $invention = invention( $redstring );
+			my $are = $redstring->{shady_group}{plural} ? 'are' : 'is';
+			my $was = $redstring->{invention_plural} ? 'were' : 'was';
+			my $invented = _RANDOM_(
+				'invented',
+				'cooked up',
+				'fabricated',
+			);
+			_RANDOM_(
+				"$group $are behind $invention",
+				"$group $invented $invention",
+				"$invention $was $invented by $group",
+			);
+		},
 	);
 	
 	_MERGE_( $redstring, hidden_truth => $truth );
@@ -1738,7 +1793,7 @@ sub theory {
 				sub {
 					my $things = _RANDOM_( 'electrons', 'protons' );
 					$redstring->{topic} = { name => $things, plural => 1 };
-					"$things are not real particles, they are just the terminal lines of a dieletric pulse";
+					"$things are not real particles, they are just the terminal lines of a dielectric pulse";
 				},
 				sub {
 					$redstring->{topic} = { name => 'water', plural => 0 };
@@ -1796,12 +1851,14 @@ sub theory {
 				"$group helped cover up the truth.",
 				"$group threatened to kill him to keep him quiet.",
 				"He was a member of $group so they knew he would keep quiet.",
+				"$group arranged a convenient \"accident\".",
 			);
 			
 			my $destruction = _RANDOM_(
 				"all of modern physics",
 				'our understanding of the universe',
 				"the Big Bang 'theory'",
+				"Einstein's theory of relativity",
 			);
 			
 			_UCFIRST_ "$physicist discovered that $fact but the scientific establishment is suppressing it because it would destroy $destruction. $solution";
@@ -1815,7 +1872,7 @@ sub theory {
 			my $fact = _RANDOM_(
 				sub {
 					$redstring->{topic} = { name => 'pandas', plural => 1 };
-					'pandas are really just fat racoons';
+					'pandas are really just fat raccoons';
 				},
 				sub {
 					$redstring->{topic} = { name => 'spaghetti', plural => 1 };
@@ -1844,7 +1901,7 @@ sub theory {
 					"essential oils cure autism";
 				},
 				sub {
-					$redstring->{topic} = { name => 'anger managemment', plural => 0 };
+					$redstring->{topic} = { name => 'anger management', plural => 0 };
 					"wasps are just angry bees";
 				},
 				sub {
@@ -1868,6 +1925,7 @@ sub theory {
 				"$group helped cover up the truth.",
 				"$group threatened to kill him to keep him quiet.",
 				"He was a member of $group so they knew he would keep quiet.",
+				"$group arranged a convenient \"accident\".",
 			);
 			
 			my $destruction = _RANDOM_(
@@ -1920,6 +1978,7 @@ sub theory {
 				"$pronoun will probably have to be eliminated",
 				"$pronoun is going to be killed if $pronoun isn't dead already",
 				"$pronoun is being paid to stay quiet",
+				"$pronoun will meet a convenient \"accident\"",
 				sub {
 					my $clone = clone( $redstring );
 					"$pronoun has been replaced by $clone";
